class Hex(object):
  key = {
    "0": 0,
    "1": 1,
    "2": 2,
    "3": 3,
    "4": 4,
    "5": 5,
    "6": 6,
    "7": 7,
    "8": 8,
    "9": 9,
    "a": 10,
    "b": 11,
    "c": 12,
    "d": 13,
    "e": 14,
    "f": 15
  }

  def __init__(self, string: str):
    self.og = Hex.make_safe(string)

  def make_safe(string: str) -> str:
    if string.startswith("#"):
      string = string[1:]
    
    for i in string:
      if i not in Hex.key:
        raise Exception("Invalid Hex Code")
    
    return string.lower()

  def convert_char(char: str) -> int:
    return Hex.key.get(char)

  def to_decimal(self) -> int:
    sum = Hex.convert_char(self.og[0])
    
    if len(self.og) == 1:
      return sum
    
    for i in self.og[1:]:
      sum *= 16
      sum += Hex.convert_char(i)
    
    return sum


if __name__ == "__main__":
  print(Hex("ff").to_decimal())



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bd103']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'bd103',
    'version': '1.1.0',
    'description': "BD103's Python Package",
    'long_description': '# BD103 Python Package\n\nWIP, come back soon!',
    'author': 'BD103',
    'author_email': 'dont@stalk.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://bd103.github.io',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from .hex import Hex


class ColorHex(object):
  def __init__(self, string: str):
    self.og = Hex.make_safe(string)

    self.red = None
    self.green = None
    self.blue = None

    self.convert()
    
  def convert(self):
    if len(self.og) == 3:
      self.red = Hex(self.og[0]).to_decimal() * 16
      self.green = Hex(self.og[1]).to_decimal() * 16
      self.blue = Hex(self.og[2]).to_decimal() * 16
    elif len(self.og) == 6:
      self.red = Hex(self.og[0:2]).to_decimal()
      self.green = Hex(self.og[2:4]).to_decimal()
      self.blue = Hex(self.og[4:6]).to_decimal()
    else:
      raise Exception("Invalid length of hex")
  
  def to_rgb(self) -> tuple:
    self.convert()
    return (self.red, self.green, self.blue)


if __name__ == "__main__":
  x = ColorHex("#0ff")
  print(x.og)
  print(x.to_rgb())
